@@ -14,8 +14,11 @@ def assert_has_columns(df, columns):
     df_columns = list(df.columns)
     missing = [col for col in columns if col not in df_columns]
     if len(missing) > 0:
-        message = f'Missing columns: "{", ".join(missing)}"'
-        message += f'\nbut has columns: "{", ".join(df_columns)}"'
+        message1 = f'Missing columns: "{", ".join(missing)}"'
+        message2 = f'but has columns: "{", ".join(df_columns)}"'
+        if len(message2) > 300:
+            message2 = message2[:200] + ' ... ' + message2[-95:]
+        message = message1 + '\n' + message2
         print(message)
         raise KeyError(message)
     else:
